@@ -123,7 +123,7 @@ class AggregateContent(BaseContent):
     key: Union[str, AggregateContentKey] = Field(
         description="The aggregate key can be either a string of a dict containing the key in field 'name'"
     )
-    content: Dict = Field(
+    content: Union[Dict, List, str, int, float, bool, None] = Field(
         description="The content of an aggregate must be a dict"
     )
 
